<?php

/**
 * This is the model class for table "tbcategory".
 *
 * The followings are the available columns in table 'tbcategory':
 * @property integer $id
 * @property string $name
 * @property integer $parent_id
 * @property string $prefix
 * @property integer $yearmonth
 * @property integer $numlimit
 */
class Category extends CActiveRecord {

    /**
     * @return string the associated database table name
     */
    public function tableName() {
        return 'tbcategory';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('parent_id, yearmonth, numlimit', 'numerical', 'integerOnly' => true),
            array('name', 'length', 'max' => 100),
            array('prefix', 'length', 'max' => 5),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('id, name, parent_id, prefix, yearmonth, numlimit', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'id' => 'ID',
            'name' => 'Name',
            'parent_id' => 'Parent',
            'prefix' => 'Prefix',
            'yearmonth' => 'Yearmonth',
            'numlimit' => 'Numlimit',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function search() {
        // @todo Please modify the following code to remove attributes that should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('id', $this->id);
        $criteria->compare('name', $this->name, true);
        $criteria->compare('parent_id', $this->parent_id);
        $criteria->compare('prefix', $this->prefix, true);
        $criteria->compare('yearmonth', $this->yearmonth);
        $criteria->compare('numlimit', $this->numlimit);

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
        ));
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return Category the static model class
     */
    public static function model($className = __CLASS__) {
        return parent::model($className);
    }

    //สร้างตาราง temp
    public function craeteTmpCategory($tableName = 'tmpcategory') {
        //ctype {0=folder, 1=file}
        $sql = "DROP TEMPORARY TABLE IF EXISTS `$tableName`;
          CREATE TEMPORARY TABLE `$tableName` (
          `id` int(11) NOT NULL AUTO_INCREMENT,
          `rowid` int(11) DEFAULT NULL,
          `parent_id` int(11) DEFAULT NULL,
          `name` text,
          `ctype` varchar(1) DEFAULT 0,
          `person_id` int(11) DEFAULT NULL,
          `docno` varchar(50) DEFAULT NULL,
          `docdate` DATE NULL,
          `tabiancode` varchar(50) DEFAULT NULL,
          `tabiandate` DATE NULL,
          PRIMARY KEY (`id`)
          ) ENGINE=MyISAM DEFAULT CHARSET=utf8;

          SET FOREIGN_KEY_CHECKS = 1;";

        Yii::app()->db->createCommand($sql)->execute();
        return true;
    }

    // Builds category list
    public function categories($category = 0, $txtsearch = '', $tmpTable = 'tmpcategory') {
        $this->craeteTmpCategory($tmpTable);
        //$sql = "SELECT  * from tbcategory WHERE parent_id = '$category' AND name like '%$txtsearch%' order by name asc";
        $sql = "SELECT  * from tbcategory WHERE parent_id = '$category' order by name asc";
        $result = Yii::app()->db->createCommand($sql)->queryAll();

        foreach ($result as $row) {
            $dot = '<i class="fa fa-lg fa-folder color-gray padding-right-10"></i>';
            $row_name = $dot . CHtml::encode($row['name']);
            $sql = "insert into $tmpTable (rowid,parent_id,name,ctype) values ('" . $row['id'] . "','$category','$row_name','0')";
            Yii::app()->db->createCommand($sql)->execute();
        }
    }

    //สร้างตัวนำทาง
    function getCategoryTreeIDs($id) {
        $model = self::model()->findByPk($id);
        $path = array();

        if ($model !== NULL) {
            if ($model->parent_id == '0') {
                $path[] = $model->id;
            } else {
                $path[] = $model->id;
                $path = array_merge($this->getCategoryTreeIDs($model->parent_id), $path);
            }
        }

        return $path;
    }

    //สร้างตัวนำทางเองโดยเรียนก getCategoryTreeIDs
    //$folder = true เปิดจาก folder , false เปิดจากแฟ้ม, $ajax = fale ใช้กับ modal เพราะต้องการให้ rediret
    function showCatBreadCrumb($catID, $folder = true, $header = '', $ajax = TRUE) {
        $array = $this->getCategoryTreeIDs($catID);
        $numItems = count($array);

        $ret = "<ol class='breadcrumb no-margin-bottom'>";

        if ($numItems == 0) {
            $ret.="<li>ตู้เอกสาร</li>";
        } else {
            if ($ajax) {
                $ret.='<li><a href="javascript:void(0);" onclick="return selectFolder(\'0\')">ตู้เอกสาร</a></li>';
            } else {
                $ret.='<li>' . CHtml::link('ตู้เอกสาร', array("/category", "cate_id" => '0')) . '</li>';
            }
        }

        for ($i = 0; $i <= $numItems - 1; $i++) {
            $model = self::model()->findByPk($array[$i]);
            if ($model->id == $catID) {
                if ($folder) {
                    $ret.= "<li>$model->name</li>";
                } else {
                    if ($ajax) {
                        $ret.='<li><a href="#" onclick="return selectFolder(\'' . $model->id . '\')">' . $model->name . '</a></li>';
                    } else {
                        $ret.='<li>' . CHtml::link($model->name, array("/category", "cate_id" => $model->id)) . '</li>';
                    }
                    $ret.="<li>$header</li>";
                }
            } else {
                if ($ajax) {
                    $ret.='<li><a href="#" onclick="return selectFolder(\'' . $model->id . '\')">' . $model->name . '</a></li>';
                } else {
                    $ret.='<li>' . CHtml::link($model->name, array("/category", "cate_id" => $model->id)) . '</li>';
                }
            }
        }

        return $ret . "</ol>";
    }

    function getCategory($parentCategoryId, $data, $countDoc = 0) {
        foreach ($data as $row) {
            if ($row['parent_id'] == $parentCategoryId) {

                $criteria = new CDbCriteria;
                $criteria->condition = "cate_id='" . $row['id'] . "'";
                $models = Doc::model()->findAll($criteria);
                $count = 0;
                foreach ($models as $r) {
                    if (Doc::model()->getSharePermission($r->id)) {
                        $count++;
                    }
                }


                $countDoc+=$count;
                $res = $this->getCategory($row['id'], $data);
                if ($res) {
                    $countDoc+=$res;
                }
            }
        }

        return $countDoc;
    }

    //นับจำนวนเอกสารในตู้
    public function countDoc($cate_id) {
        $sql = "select * from tbcategory";
        $data = Yii::app()->db->createCommand($sql)->queryAll();
        $countDoc = $this->getCategory($cate_id, $data);

        //รวมเอกสารที่อยู่ในตู้ตัวเองด้วย
        $criteria = new CDbCriteria;
        $criteria->condition = "cate_id='$cate_id'";
        $models = Doc::model()->findAll($criteria);
        foreach ($models as $r) {
            if (Doc::model()->getSharePermission($r->id)) {
                $countDoc++;
            }
        }
        return $countDoc;
    }

}
