<?php

/**
 * This is the model class for table "tbdoc".
 *
 * The followings are the available columns in table 'tbdoc':
 * @property integer $id
 * @property string $name
 * @property string $tabiancode
 * @property string $docno
 * @property string $docdate
 * @property integer $cate_id
 * @property string $cdate
 * @property string $ctime
 * @property string $startdate
 * @property string $expdate
 * @property integer $status
 * @property string $comment
 * @property integer $person_id
 * @property string $tabiandate
 */
class Doc extends CActiveRecord {

    /**
     * @return string the associated database table name
     */
    public function tableName() {
        return 'tbdoc';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('cate_id, status, person_id', 'numerical', 'integerOnly' => true),
            array('name', 'length', 'max' => 200),
            array('tabiancode, docno', 'length', 'max' => 50),
            array('ctime', 'length', 'max' => 10),
            array('docdate, cdate, startdate, expdate, comment, tabiandate', 'safe'),
            // The following rule is used by search().
            // @todo Please remove those attributes that should not be searched.
            array('id, name, tabiancode, docno, docdate, cate_id, cdate, ctime, startdate, expdate, status, comment, person_id, tabiandate', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'person' => array(self::BELONGS_TO, 'Person', 'person_id'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'id' => 'ID',
            'name' => 'Name',
            'tabiancode' => 'Tabiancode',
            'docno' => 'Docno',
            'docdate' => 'Docdate',
            'cate_id' => 'Cate',
            'cdate' => 'Cdate',
            'ctime' => 'Ctime',
            'startdate' => 'Startdate',
            'expdate' => 'Expdate',
            'status' => 'Status',
            'comment' => 'Comment',
            'person_id' => 'Person',
            'tabiandate' => 'Tabiandate',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * Typical usecase:
     * - Initialize the model fields with values from filter form.
     * - Execute this method to get CActiveDataProvider instance which will filter
     * models according to data in model fields.
     * - Pass data provider to CGridView, CListView or any similar widget.
     *
     * @return CActiveDataProvider the data provider that can return the models
     * based on the search/filter conditions.
     */
    public function search() {
        // @todo Please modify the following code to remove attributes that should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('id', $this->id);
        $criteria->compare('name', $this->name, true);
        $criteria->compare('tabiancode', $this->tabiancode, true);
        $criteria->compare('docno', $this->docno, true);
        $criteria->compare('docdate', $this->docdate, true);
        $criteria->compare('cate_id', $this->cate_id);
        $criteria->compare('cdate', $this->cdate, true);
        $criteria->compare('ctime', $this->ctime, true);
        $criteria->compare('startdate', $this->startdate, true);
        $criteria->compare('expdate', $this->expdate, true);
        $criteria->compare('status', $this->status);
        $criteria->compare('comment', $this->comment, true);
        $criteria->compare('person_id', $this->person_id);
        $criteria->compare('tabiandate', $this->tabiandate);

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
        ));
    }

    /**
     * Returns the static model of the specified AR class.
     * Please note that you should have this exact method in all your CActiveRecord descendants!
     * @param string $className active record class name.
     * @return Doc the static model class
     */
    public static function model($className = __CLASS__) {
        return parent::model($className);
    }

    /**
     * ตรวจสอบรหัสซ้ำ
     */
    function checkDuplicate($id, $value) {
        $model = $this->findByAttributes(array('tabiancode' => $value));

        $msg = '0';
        $msgText = '';
        if ($model !== null) {
            if ($model->id != $id) {
                $msgText = "เลขทะเบียน $value มีการใช้งานแล้ว...กรุณาเปลี่ยนใหม่.";
                $msg = '1';
            }
        }

        return array('msg' => $msg, 'msgText' => $msgText);
    }

    //สร้างเลขที่เอกสาร
    public function getDocrun($cate_id) {
        $model = Category::model()->findByPk($cate_id);
        $model->numlimit = ($model->numlimit === NULL) ? '3' : $model->numlimit;

        if ($model->yearmonth == '0') {
            $current_daterun = MyDate::currentYearMonthThai();
        } else {
            $current_daterun = '';
        }

        $prefix = $model->prefix . $current_daterun;
        $sql = "Select Max(substr(tabiancode,-$model->numlimit))+1 as maxId from tbdoc where tabiancode LIKE '$prefix%'";
        $query = Yii::app()->db->createCommand($sql)->queryRow();
        if ($query['maxId'] == null) {
            return $prefix . sprintf("%0" . $model->numlimit . "d", 1);
        } else {
            return $prefix . sprintf("%0" . $model->numlimit . "d", $query['maxId']);
        }
    }

    public function getStatusText($status) {
        $ret = '';
        switch ($status) {
            case '0':
                $ret = 'เผยแพร่';
                break;
            case '1':
                $ret = 'ระงับการเผยแพร่';
                break;
            case '2':
                $ret = 'กำหนดวันหมดอายุ';
                break;
        }

        return $ret;
    }

    //ตรวจสอบสิทธิ์การเข้าถึงแฟ้ม
    function getSharePermission($doc_id) {
        $docdepart = DocDepart::model()->findByAttributes(array(
            'doc_id' => (int) $doc_id,
            'depart_id' => Yii::app()->user->getState('depart_id')
        ));

        //ตรวจสอบระดับแผนก
        $ret = FALSE;
        if ($docdepart !== NULL) {
            $ret = TRUE;
        }

        //ถ้ากลุ่มนี้ถูกกำหนดให้เข้าถึงได้ทุกแฟ้ม ให้อ่านได้โดยไม่ต้องแชร์
        $group = Group::model()->findByPk(Yii::app()->user->getState('group_id'));
        if ($group !== NULL) {
            if ($group->readall == '1') {
                $ret = TRUE;
            }
        }

        //ตรวจสอบระบบบุคค
        $docperson = DocPerson::model()->findByAttributes(array(
            'doc_id' => (int) $doc_id,
            'person_id' => Yii::app()->user->id,
        ));

        if ($docperson !== NULL) {
            if ($docperson->status == '1') {
                //สถานะนี้แสดงว่ากำหนดไว้ว่าห้ามเข้าถึง
                $ret = FALSE;
            } else {
                $ret = TRUE;
            }
        }


        $doc = Doc::model()->findByPk((int) $doc_id);
        //ตรวจสอบสถานะของเอกสาร
        $currentDate = date('Y-m-d');
        if ($doc->status == '1') {
            $ret = FALSE;   //ระงับการเผยแพร่
        } else if ($doc->status == '0') {
            //เผยแพร่ ให้ตรวจสอบวันที่ว่าให้เริ่มเผยแพร่วันไหน
            if ($doc->startdate <= $currentDate) {
                //$ret = TRUE;
            } else {
                $ret = FALSE;
            }
        } else if ($doc->status == '2') {
            //เผยแพร่ตามช่วงวันที่
            if ($doc->startdate <= $currentDate && $doc->expdate >= $currentDate) {
                //$ret = TRUE;
            } else {
                $ret = FALSE;
            }
        }


        //ถ้าแฟ้มเอกสารเป็นของผู้ login ให้เข้าถึงได้โดยไม่ต้องแชร์ และไม่ต้องสนใจเงื่อนไขใดๆ
        if ($doc->person_id == Yii::app()->user->id) {
            $ret = TRUE;
        }

        return $ret;
    }

}
